######################################################################
#
# English Language text and icon macros 
#
######################################################################
#
# This is the main macro file for translation when creating an 
# interface in another language.
#
# Under the 'text macros' comments are text macros of the form:
# _macroname_ [l=id] {macro value}
# Everything between the [l=id] {} is the text to be translated. This text 
# may itself contain macros (i.e. characters other than space between
# underscore characters, e.g. _about:numdocs_ or _textpage_). These
# macro names occurring within text shouldn't be translated but should
# be left as they are. Underscores or curly brackets occurring 
# naturally within the text should be escaped with a leading backslash
# (i.e. '\_', '\[l=id] {' or '\}).
#
# Under the 'icons' comments are macros concerned with displaying
# icons which themselves contain text.
# Above each macro (or group of macros) for an icon is a comment line
# that looks something like '## "HOME" ## top_nav_button ## chome ##'.
# The first field of the comment ("HOME" in this case) is the text
# that appears in the english version of the icon. This is the text
# that must be translated, nothing needs to be done to the macros 
# themselves. The other two fields of the comments are used by 
# automatic icon generating software which reads the newly translated
# file and generates appropriate icons.
#
# Comment lines (other than those described above) need not be 
# translated (i.e. any lines beginning with '#', like this line).
#
# The simplest way to translate this file is to save it as something
# else (e.g. french.dm) and work through translating all the text
# macro values and icon comments.
#
######################################################################


######################################################################
# Global (base) package
package Global
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textdefaultcontent_ [l=id] {Halaman yang diminta tidak dapat ditemukan. Mohon gunakan tombol 'Back' (balik) di browser anda atau tombol Induk di atas untuk kembali ke Perpustakaan Digital Greenstone.}

_textdefaulttitle_ [l=id] {Kesalahan GSDL }

_collectionextra_ [l=id] {Koleksi ini mengandung _about:numdocs_ dokumen. 
Koleksi terbentuk _about:builddate_ hari yang lalu.}

# this is only used by the collector (where the above _collectionextra_
# macro will always be set to another value)
_collectorextra_ [l=id] {
<p>Koleksi ini mengandung _numdocs_ _If_("_numdocs_" eq "1",dokumen,dokumen), dengan jumlah _numbytes_.
}

_textimagecollection_ [l=id] {}
_textimageabout_ [l=id] {Halaman Perihal}
_textimagehome_ [l=id] {Halaman Induk}
_textimagehelp_ [l=id] {Halaman Bantuan}
_textimagepref_ [l=id] {Halaman Preferensi}
_textimagegreenstone_ [l=id] {Perangkat Lunak Perpustakaan Digital Greenstone}

_textimagesearch_ [l=id] {Mencari istilah tertentu}
_textimageTitle_ [l=id] {Melihat judul buku menurut abjad}
_textimageList_ [l=id] {Melihat daftar dokumen}
_textimageCreator_ [l=id] {Melihat pengarang buku menurut abjad}
_textimageSeries_ [l=id] {Melihat menurut terbitan}
_textimageDate_ [l=id] {Melihat menurut tanggal}
_textimageSubject_ [l=id] {Melihat menurut kategori subyek}
_textimageTo_ [l=id] {Melihat menurut bidang Kepada}
_textimageFrom_ [l=id] {Melihat menurut bidang Dari}
_textimageOrganization_ [l=id] {Melihat menurut organisasi}
_textimageHowto_ [l=id] {Melihat kategori Bagaimana}
_textimageTopic_ [l=id] {Melihat terbitan khusus}
_textimageBrowse_ [l=id] {Melihat}
_textimagePeople_ [l=id] {Melihat daftar orang menurut abjad}
_textimageLanguage_ [l=id] {Melihat menurut bahasa}
_textimageAcronym_ [l=id] {Melihat singkatan lembaga}
_textimagePhrase_ [l=id] {Melihat ungkapan}

_texticontabsearchgreen_ [l=id] {Mencari}
_texticontabdategreen_ [l=id] {Tanggal}
_texticontabseriesgreen_ [l=id] {Berkala}
_texticontabauthorgreen_ [l=id] {Pengarang A-Z}
_texticontabtitlegreen_ [l=id] {Judul A-Z}
_texticontablistgreen_ [l=id] {Daftar}
_texticontabsubjectgreen_ [l=id] {Subyek}
_texticontabtogreen_ [l=id] {Kepada}
_texticontabfromgreen_ [l=id] {Dari}
_texticontaborggreen_ [l=id] {Organisasi}
_texticontabhowgreen_ [l=id] {Bagaimana}
_texticontabtopicgreen_ [l=id] {Topik}
_texticontabbrwsegreen_ [l=id] {Melihat}
_texticontabPeoplegreen_ [l=id] {Orang A-Z}
_texticontabLanguagegreen_ [l=id] {Bahasa}
_texticontabAcronymgreen_ [l=id] {Singkatan}
_texticontabPhrasegreen_ [l=id] {Ungkapan}

_texticontext_ [l=id] {Menampilkan dokumen}
_texticonclosedbook_ [l=id] {Membuka dokumen ini dan melihat isinya}
_texticonnext_ [l=id] {ke bagian berikut}
_texticonprev_ [l=id] {ke bagian sebelumnya}

_texticonmidi_ [l=id] {Melihat dokumen MIDI}
_texticonmsword_ [l=id] {Melihat dokumen Microsoft Word}
_texticonpdf_ [l=id] {Melihat dokumen PDF}
_texticonps_ [l=id] {Melihat dokumen PS}
_texticonppt_ [l=id] {Melihat dokumen PPT}
_texticonrtf_ [l=id] {Melihat dokumen RTF}
_texticonxls_ [l=id] {Melihat dokumen XLS}

_page_ [l=id] {halaman }
_pages_ [l=id] {halaman}
_of_ [l=id] { dari }
_vol_ [l=id] {Vol.}
_num_ [l=id] {No.}

_textmonth00_ [l=id] {}
_textmonth01_ [l=id] {Januari}
_textmonth02_ [l=id] {Pebruari}
_textmonth03_ [l=id] {Maret}
_textmonth04_ [l=id] {April}
_textmonth05_ [l=id] {Mei}
_textmonth06_ [l=id] {Juni}
_textmonth07_ [l=id] {Juli}
_textmonth08_ [l=id] {Agustus}
_textmonth09_ [l=id] {September}
_textmonth10_ [l=id] {Oktober}
_textmonth11_ [l=id] {Nopember}
_textmonth12_ [l=id] {Desember}

_textdocument_ [l=id] {Dokumen}
_textsection_ [l=id] {Bagian}
_textparagraph_ [l=id] {Alinea}

_magazines_ [l=id] {Majalah}

_nzdlpagefooter_ [l=id] {<p>_iconblankbar_
<p><a href="http://www.nzdl.org">New Zealand Digital Library Project</a>
<br><a href="http://www.cs.waikato.ac.nz/cs">Department of Computer Science</a>, 
<a href="http://www.waikato.ac.nz">University of Waikato</a>, 
New Zealand}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "INDUK" ## top_nav_button ## chome ##
_httpiconchomeof_ [l=id] {_httpimg_/id/chomeof.gif}
_httpiconchomeon_ [l=id] {_httpimg_/id/chomeon.gif}

## "BANTUAN" ## top_nav_button ## chelp ##
_httpiconchelpof_ [l=id] {_httpimg_/id/chelpof.gif}
_httpiconchelpon_ [l=id] {_httpimg_/id/chelpon.gif}

## "PREFERENSI" ## top_nav_button ## cpref ##
_httpiconcprefof_ [l=id] {_httpimg_/id/cprefof.gif}
_httpiconcprefon_ [l=id] {_httpimg_/id/cprefon.gif}

## "bantuan" ## green_title ## h_help ##
_httpiconhhelp_ [l=id] {_httpimg_/id/h\_help.gif}
_widthhhelp_ [l=id] {200}
_heighthhelp_ [l=id] {57}

## "pengarang a-z" ## nav_bar_button ## tauth ##
_httpicontauthgr_ [l=id] {_httpimg_/id/tauthgr.gif}
_httpicontauthof_ [l=id] {_httpimg_/id/tauthof.gif}
_httpicontauthon_ [l=id] {_httpimg_/id/tauthon.gif}
_widthtauthx_ [l=id] {125}

## "berkala" ## nav_bar_button ## tser ##
_httpicontsergr_ [l=id] {_httpimg_/id/tsergr.gif}
_httpicontserof_ [l=id] {_httpimg_/id/tserof.gif}
_httpicontseron_ [l=id] {_httpimg_/id/tseron.gif}
_widthtserx_ [l=id] {87}

## "tanggal" ## nav_bar_button ## tdate ##
_httpicontdategr_ [l=id] {_httpimg_/id/tdategr.gif}
_httpicontdateof_ [l=id] {_httpimg_/id/tdateof.gif}
_httpicontdateon_ [l=id] {_httpimg_/id/tdateon.gif}
_widthtdatex_ [l=id] {87}

## "subyek" ## nav_bar_button ## tsubj ##
_httpicontsubjgr_ [l=id] {_httpimg_/id/tsubjgr.gif}
_httpicontsubjon_ [l=id] {_httpimg_/id/tsubjon.gif}
_httpicontsubjof_ [l=id] {_httpimg_/id/tsubjof.gif}
_widthtsubjx_ [l=id] {87}

## "kepada" ## nav_bar_button ## tto ##
_httpiconttogr_ [l=id] {_httpimg_/id/ttogr.gif}
_httpiconttoon_ [l=id] {_httpimg_/id/ttoon.gif}
_httpiconttoof_ [l=id] {_httpimg_/id/ttoof.gif}
_widthttox_ [l=id] {87}

## "dari" ## nav_bar_button ## tfrom ##
_httpicontfromgr_ [l=id] {_httpimg_/id/tfromgr.gif}
_httpicontfromon_ [l=id] {_httpimg_/id/tfromon.gif}
_httpicontfromof_ [l=id] {_httpimg_/id/tfromof.gif}
_widthtfromx_ [l=id] {87}

## "organisasi" ## nav_bar_button ## torg ##
_httpicontorggr_ [l=id] {_httpimg_/id/torggr.gif}
_httpicontorgon_ [l=id] {_httpimg_/id/torgon.gif}
_httpicontorgof_ [l=id] {_httpimg_/id/torgof.gif}
_widthtorgx_ [l=id] {87}

## "bagaimana" ## nav_bar_button ## thow ##
_httpiconthowgr_ [l=id] {_httpimg_/id/thowgr.gif}
_httpiconthowon_ [l=id] {_httpimg_/id/thowon.gif}
_httpiconthowof_ [l=id] {_httpimg_/id/thowof.gif}
_widththowx_ [l=id] {93}

## "topik" ## nav_bar_button ## ttopic ##
_httpiconttopicgr_ [l=id] {_httpimg_/id/ttopicgr.gif}
_httpiconttopicon_ [l=id] {_httpimg_/id/ttopicon.gif}
_httpiconttopicof_ [l=id] {_httpimg_/id/ttopicof.gif}
_widthttopicx_ [l=id] {87}

## "melihat" ## nav_bar_button ## tbrwse ##
_httpicontbrwsegr_ [l=id] {_httpimg_/id/tbrwsegr.gif}
_httpicontbrwseon_ [l=id] {_httpimg_/id/tbrwseon.gif}
_httpicontbrwseof_ [l=id] {_httpimg_/id/tbrwseof.gif}
_widthtbrwsex_ [l=id] {87}

## "mencari" ## nav_bar_button ## tsrch ##
_httpicontsrchgr_ [l=id] {_httpimg_/id/tsrchgr.gif}
_httpicontsrchof_ [l=id] {_httpimg_/id/tsrchof.gif}
_httpicontsrchon_ [l=id] {_httpimg_/id/tsrchon.gif}
_widthtsrchx_ [l=id] {87}

## "judul a-z" ## nav_bar_button ## ttitl ##
_httpiconttitlgr_ [l=id] {_httpimg_/id/ttitlgr.gif}
_httpiconttitlof_ [l=id] {_httpimg_/id/ttitlof.gif}
_httpiconttitlon_ [l=id] {_httpimg_/id/ttitlon.gif}
_widthttitlx_ [l=id] {87}

## "orang" ## nav_bar_button ## tpeop ##
_httpicontpeopgr_ [l=id] {_httpimg_/id/tpeopgr.gif}
_httpicontpeopof_ [l=id] {_httpimg_/id/tpeopof.gif}
_httpicontpeopon_ [l=id] {_httpimg_/id/tpeopon.gif}
_widthtpeopx_ [l=id] {87}

## "bahasa" ## nav_bar_button ## tlang ##
_httpicontlanggr_ [l=id] {_httpimg_/id/tlanggr.gif}
_httpicontlangon_ [l=id] {_httpimg_/id/tlangon.gif}
_httpicontlangof_ [l=id] {_httpimg_/id/tlangof.gif}
_widthtlangx_ [l=id] {87}

## "singkatan" ## nav_bar_button ## tacro ##
_httpicontacrogr_ [l=id] {_httpimg_/id/tacrogr.gif}
_httpicontacroof_ [l=id] {_httpimg_/id/tacroof.gif}
_httpicontacroon_ [l=id] {_httpimg_/id/tacroon.gif}
_widthtacrox_ [l=id] {87}

## "ungkapan" ## nav_bar_button ## tphrse ##
_httpicontphrsegr_ [l=id] {_httpimg_/id/tphrsegr.gif}
_httpicontphrseof_ [l=id] {_httpimg_/id/tphrseof.gif}
_httpicontphrseon_ [l=id] {_httpimg_/id/tphrseon.gif}
_widthtphrsex_ [l=id] {87}


######################################################################
# 'about' page
package about
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textabcol_ [l=id] {Mengenai koleksi ini}

_textsubcols1_ [l=id] {<p>Koleksi lengkap mengandung _1_ subkoleksi. 
Koleksi yang sedang tersedia adalah:
<blockquote>}

_textsubcols2_ [l=id] {</blockquote>
Anda dapat mengecek (dan mengubah) subkoleksi yang sedang digunakan 
pada halaman Preferensi.}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "about" ## green_title ## h_about ##
_httpiconhabout_ [l=id] {_httpimg_/id/h\_about.gif}
_widthhabout_ [l=id] {200}
_heighthabout_ [l=id] {57}



######################################################################
# document package
package document
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textTitlepage_ [l=id] {_texticonhtitle_}
_textCreatorpage_ [l=id] {_texticonhauth_}
_textSubjectpage_ [l=id] {_texticonhsubj_}
_textTopage_ [l=id] {_texticonhto_}
_textFrompage_ [l=id] {_texticonhfrom_}
_textSeriespage_ [l=id] {_texticonhser_}
_textDatepage_ [l=id] {_texticonhdate_}
_textHowtopage_ [l=id] {_texticonhhow_}
_textOrganizationpage_ [l=id] {_texticonhorg_}
_textBrowsepage_ [l=id] {_texticonhbrwse_}
_textPeoplepage_ [l=id] {_texticonhpeople_}
_textLanguagepage_ [l=id] {_texticonhlanguage_}
_textAcronympage_ [l=id] {_texticonhacronym_}
_textPhrasepage_ [l=id] {_texticonhphrases_}

_texticonhtitle_ [l=id] {Judul A-Z}
_texticonhauth_ [l=id] {Pengarang A-Z}
_texticonhsubj_ [l=id] {Subyek}
_texticonhto_ [l=id] {Kepada}
_texticonhfrom_ [l=id] {Dari}
_texticonhser_ [l=id] {Berkala}
_texticonhdate_ [l=id] {Tanggal}
_texticonhhow_ [l=id] {Bagaimana}
_texticonhorg_ [l=id] {Organisasi}
_texticonhbrwse_ [l=id] {Melihat}
_texticonhpeople_ [l=id] {Orang A-Z}
_texticonhlanguage_ [l=id] {Bahasa}
_texticonhacronym_ [l=id] {Singkatan}
_texticonhphrases_ [l=id] {Ungkapan}

_texticonopenbookshelf_ [l=id] {tutup bagian perpustakaan ini}
_texticonclosedbookshelf_ [l=id] {buka bagian perpustakaan ini dan melihat isinya}
_texticonopenbook_ [l=id] {tutup buku ini}
_texticonclosedfolder_ [l=id] {Buka map ini dan melihat isinya}
_texticonclosedfolder2_ [l=id] {buka sub-bagian: }
_texticonopenfolder_ [l=id] {tutup map ini}
_texticonopenfolder2_ [l=id] {tutup sub-bagian: }
_texticonsmalltext_ [l=id] {Melihat bagian ini dari teks}
_texticonsmalltext2_ [l=id] {melihat teks: }
_texticonpointer_ [l=id] {bagian terpilih}
_texticondetach_ [l=id] {Bukan halaman ini pada jendela baru}
_texticonhighlight_ [l=id] {Menyoroti istilah yang dicari}
_texticonnohighlight_ [l=id] {Jangan menyoroti istilah yang dicari}
_texticoncontracttoc_ [l=id] {Tutup daftar isi}
_texticonexpandtoc_ [l=id] {Buka daftar isi}
_texticonexpandtext_ [l=id] {Tampilkan semua teks}
_texticoncontracttext_ [l=id] {Tampilkan teks hanya di bagian yang terpilih}
_texticonwarning_ [l=id] {<b>Perhatian: </b>}
_texticoncont_ [l=id] {teruskan?}

_textltwarning_ [l=id] {
<p><center>
<table cellspacing=0 cellpadding=0 width=_pagewidth_>
<tr valign=top><td>_iconwarning_Membuka teks di sini akan menghasilkan sejumlah data besar untuk ditampilkan oleh browser anda _imagecont_
</td></tr></table></center>
}

_textgoto_ [l=id] {ke halaman}
_textintro_ [l=id] { <i>(teks pengantar)</i>}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "Judul A-Z" ## green_title ## h_title ##
_httpiconhtitle_ [l=id] {_httpimg_/id/h\_title.gif}
_widthhtitle_ [l=id] {200}
_heighthtitle_ [l=id] {57}

## "pengarang a-z" ## green_title ## h_auth ##
_httpiconhauth_ [l=id] {_httpimg_/id/h\_auth.gif}
_widthhauth_ [l=id] {200}
_heighthauth_ [l=id] {57}

## "subyek" ## green_title ## h_subj ##
_httpiconhsubj_ [l=id] {_httpimg_/id/h\_subj.gif}
_widthhsubj_ [l=id] {200}
_heighthsubj_ [l=id] {57}

## "kepada" ## green_title ## h_to ##
_httpiconhto_ [l=id] {_httpimg_/id/h\_to.gif}
_widthhto_ [l=id] {200}
_heighthto_ [l=id] {57}

## "dari" ## green_title ## h_from ##
_httpiconhfrom_ [l=id] {_httpimg_/id/h\_from.gif}
_widthhfrom_ [l=id] {200}
_heighthfrom_ [l=id] {57}

## "berkala" ## green_title ## h_ser ##
_httpiconhser_ [l=id] {_httpimg_/id/h\_ser.gif}
_widthhser_ [l=id] {200}
_heighthser_ [l=id] {57}

## "tanggal" ## green_title ## h_date ##
_httpiconhdate_ [l=id] {_httpimg_/id/h\_date.gif}
_widthhdate_ [l=id] {200}
_heighthdate_ [l=id] {57}

## "bagaimana" ## green_title ## h_how ##
_httpiconhhow_ [l=id] {_httpimg_/id/h\_how.gif}
_widthhhow_ [l=id] {200}
_heighthhow_ [l=id] {57}

## "topik" ## green_title ## h_topic ##
_httpiconhtopic_ [l=id] {_httpimg_/id/h\_topic.gif}
_widthhtopic_ [l=id] {200}
_heighthtopic_ [l=id] {57}

## "organisasi" ## green_title ## h_org ##
_httpiconhorg_ [l=id] {_httpimg_/id/h\_org.gif}
_widthhorg_ [l=id] {250}
_heighthorg_ [l=id] {57}

## "melihat" ## green_title ## h_brwse ##
_httpiconhbrwse_ [l=id] {_httpimg_/id/h\_brwse.gif}
_widthhbrwse_ [l=id] {200}
_heighthbrwse_ [l=id] {57}

## "orang" ## green_title ## h_people ##
_httpiconhpeople_ [l=id] {_httpimg_/id/h\_people.gif}
_widthhpeople_ [l=id] {200}
_heighthpeople_ [l=id] {57}

## "bahasa" ## green_title ## h_lang ##
_httpiconhlanguage_ [l=id] {_httpimg_/id/h\_lang.gif}
_widthhlanguage_ [l=id] {200}
_heighthlanguage_ [l=id] {57}

## "singkatan" ## green_title ## h_acro ##
_httpiconhacronym_ [l=id] {_httpimg_/id/h\_acro.gif}
_widthhacronym_ [l=id] {200}
_heighthacronym_ [l=id] {57}

## "ungkapan" ## green_title ## h_phrse ##
_httpiconhphrse_ [l=id] {_httpimg_/id/h\_phrse.gif}
_widthhphrse_ [l=id] {200}
_heighthphrse_ [l=id] {57}

## "TERUSKAN?" ## top_nav_button ## cont ##
_httpiconcontoff_ [l=id] {_httpimg_/id/contof.gif}
_httpiconconton_ [l=id] {_httpimg_/id/conton.gif}

## "BUKA TEKS" ## document_button ## eallt ## 
_httpiconealltof_ [l=id] {_httpimg_/id/ealltof.gif}
_httpiconeallton_ [l=id] {_httpimg_/id/eallton.gif}

## "TUTUP ISI" ## document_button ## econc ##
_httpiconeconcof_ [l=id] {_httpimg_/id/econcof.gif}
_httpiconeconcon_ [l=id] {_httpimg_/id/econcon.gif}

## "PISAHKAN" ## document_button ## edtch ##
_httpiconedtchof_ [l=id] {_httpimg_/id/edtchof.gif}
_httpiconedtchon_ [l=id] {_httpimg_/id/edtchon.gif}

## "BUKA ISI" ## document_button ## eexpc ##
_httpiconeexpcof_ [l=id] {_httpimg_/id/eexpcof.gif}
_httpiconeexpcon_ [l=id] {_httpimg_/id/eexpcon.gif}

## "TUTUP TEKS" ## document_button ## etsec ##
_httpiconetsecof_ [l=id] {_httpimg_/id/etsecof.gif}
_httpiconetsecon_ [l=id] {_httpimg_/id/etsecon.gif}

## "PENYOROTAN" ## document_button ## ehl ##
_httpiconehlof_ [l=id] {_httpimg_/id/ehlof.gif}
_httpiconehlon_ [l=id] {_httpimg_/id/ehlon.gif}

## "      TANPA 
#PENYOROTAN" ## document_button ## enhl ##
_httpiconenhlof_ [l=id] {_httpimg_/id/enhlof.gif}
_httpiconenhlon_ [l=id] {_httpimg_/id/enhlon.gif}


######################################################################
# 'search' page
package query
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

# this if statement produces the text 'results n1 - nn for query: querystring' or 
# 'No matches for query: querystring', depending on whether or not there were
# any matches
_textquerytitle_ [l=id] {_If_(_thislast_,hasil _thisfirst_ - _thislast_ untuk pertanyaan: _cgiargq_,Tidak ada yang memenuhi syarat: _cgiargq_)}
_textnoquerytitle_ [l=id] {Halaman Pencarian}

_texticonthispage_ [l=id] {mencari}
_textsome_ [l=id]{beberapa}
_textall_ [l=id]{semua}
_textboolean_ [l=id]{logika}
_textranked_ [l=id]{terurut}
_textnatural_ [l=id]{alami}
#_textsome_ [l=id] {_If_(_cgiargb_,terurut,beberapa)}
#_textall_ [l=id] {_If_(_cgiargb_,logika,semua)}
#_textformsome_ [l=id] {_If_(_cgiargb_,terurut,beberapa)}
#_textformall_ [l=id] {_If_(_cgiargb_,alami,semua)}
_texticonqueryresultsbar_ [l=id] {}
_texticonsearchhistorybar_ [l=id] {riwayat pencarian}

#alt text for query buttons
_textusequery_ [l=id] {gunakan pertanyaan ini}
_textfreqmsg1_ [l=id] {Jumlah kata: }
_textpostprocess_ [l=id] {_If_(_quotedquery_,<br><i>diproses ulang untuk menemukan _quotedquery_</i>
)}

_textmorethan_ [l=id] {Lebih dari }
_textapprox_ [l=id] {Sekitar }
_textnodocs_ [l=id] {Tidak ada dokumen yang memenuhi syarat.}
_text1doc_ [l=id] {1 dokumen memenuhi syarat.}
_textlotsdocs_ [l=id] {dokumen memenuhi syarat.}
_textmatches_ [l=id] {Penemuan }
_textbeginsearch_ [l=id] {Mulai mencari}
_textrunquery_ [l=id] {Menjalankan pertanyaan}
_textclearform_ [l=id] {Menghapuskan formulir}

#these go together in form search:
#"Word or phrase  (fold, stem)  ... in field"
_textwordphrase_ [l=id] {Kata atau ungkapan}
_textinfield_ [l=id] {... dalam bidang}
_textfoldstem_ [l=id] {(lipatan, kata dasar)}

_textadvquery_ [l=id] {Atau masukkan pertanyaan secara langsung:}
_textallfields_ [l=id] {Semua bidang}
_textand_ [l=id] {dan}
_textor_ [l=id] {atau}
_textandnot_ [l=id] {dan tidak}

# _hselection_, _jselection_, _nselection_ and _gselection_ are set from 
# within the server some or all of them may remain unset


_textsimplesearch_ [l=id] {Mencari _If_(_hselection_, _hselection_) _If_(_jselection_, _textjselect_) _If_(_gselection_, pada tingkat _gselection_) _If_(_nselection_, dalam bahasa _nselection_)
yang mengandung _querytypeselection_ dari kata}

_textadvancedsearch_ [l=id] {Mencari _If_(_hselection_, _hselection_, _defaultindextext_) _If_(_jselection_,_textjselect_) _If_(_gselection_, pada tigkat _gselection_)_If_(_nselection_, dalam bahasa _nselection_) 
dengan menggunakan pertanyaan _querytypeselection_}

_textformsimplesearch_ [l=id] {Mencari _If_(_hselection_, _hselection_) _If_(_jselection_, _textjselect_) _If_(_gformselection_, pada tingkat _gformselection_) _If_(_nselection_, dalam bahasa _nselection_)
yang mengandung _formquerytypeselection_ dari}

_textformadvancedsearch_ [l=id] {Mencari _If_(_hselection_, _hselection_, _defaultindextext_) _If_(_jselection_,_textjselect_) _If_(_gformselection_, pada tingkat _gformselection_)_If_(_nselection_, dalam bahasa _nselection_) 
dan menampilkan hasil dalam urutan _formquerytypeselection_}


_textjselect_ [l=id] {_If_(_hselection_, dari) _jselection_}

_textdatesearch_ [l=id] {Koleksi ini dapat diselidiki untuk dokumen yang mengandung tahun atau kisaran tahun tertentu. Kemungkinan ini merupakan pilihan tambahan.}
_textstartdate_ [l=id] {Tahun mulai (atau tunggal):}
_textenddate_ [l=id] {Tahun akhir:}
_textbc_ [l=id] {SM}
_textad_ [l=id] {TM}
_textexplaineras_ [l=id] {SM = sebelum Masehi, TM = Tarich (sesudah) Masehi} 

_textstemon_ [l=id] { (mengabaikan akhiran kata)}

_textsearchhistory_ [l=id] {Riwayat pencarian}

#text macros for search history
_textnohistory_ [l=id] {Riwayat pencarian tidak tersedia}
_texthresult_ [l=id] {hasil}
_texthresults_ [l=id] {hasil}
_texthallwords_ [l=id] {semua kata}
_texthsomewords_ [l=id] {beberapa kata}
_texthboolean_ [l=id] {pencarian logika}
_texthranked_ [l=id] {terurut}
_texthcaseon_ [l=id] {Huruf besar/kecil harus sama}
_texthcaseoff_ [l=id] {Abaikan huruf besar/kecil}
_texthstemon_ [l=id] {Abaikan awalan dan akhiran}
_texthstemoff_ [l=id] {Dengan awalan dan akhiran}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "Mencari" ## green_title ## h_search ##
_httpiconhsearch_ [l=id] {_httpimg_/id/h\_search.gif}
_widthhsearch_ [l=id] {200}
_heighthsearch_ [l=id] {57}

## "Hasil" ## green_bar_left_aligned ## qryresb ##
_httpiconqryresb_ [l=id] {_httpimg_/id/qryresb.gif}
_widthqryresb_ [l=id] {_pagewidth_}
_heightqryresb_ [l=id] {17}

## "Riwayat" ## green_bar_left_aligned ## schhistb ##
_httpiconsrchhistb_ [l=id] {_httpimg_/id/schhistb.gif}
_widthsrchhistb_ [l=id] {_pagewidth_}
_heightsrchhistb_ [l=id] {17}

## "Tampilkan" ## hand_made ##
_httpicondisplay_ [l=id] {_httpimg_/display.gif}
_widthdisplay_ [l=id] {60}
_heightdisplay_ [l=id] {20}


######################################################################
# 'preferences' page
package preferences
######################################################################

#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textprefschanged_ [l=id] {Preferensi ditetapkan seperti berikut. Jangan menggunakan tombol &quot;back&quot; di browser anda - preferensi tersebut akan terhapus! Daripada itu, klik di salah satu tombol di atas.}
_textsetprefs_ [l=id] {tetapkan preferensi}
_textsearchprefs_ [l=id] {Preferensi pencarian}
_textcollectionprefs_ [l=id] {Preferensi koleksi}
_textpresentationprefs_ [l=id] {Preferensi penampilan}
_textpreferences_ [l=id] {Preferensi}
_textcasediffs_ [l=id] {Pembedaan huruf besar/kecil:}
_textignorecase_ [l=id] { abaikan perbedaan}
_textmatchcase_ [l=id] { huruf besar/kecil harus tepat sama}
_textwordends_ [l=id] {Akhiran kata:}
_textstem_ [l=id] { abaikan akhiran}
_textnostem_ [l=id] { kata harus tepat sama}
_textprefop_ [l=id] {Sediakan sampai dengan _maxdocoption_ penemuan dengan _hitsperpageoption_ penemuan per halaman.}
_textextlink_ [l=id] {Akses ke halaman web di luar:}
_textintlink_ [l=id] {Dokumen asli diperoleh dari:}
_textlanguage_ [l=id] {Bahasa tampilan:}
_textencoding_ [l=id] {Pengekodean:}
_textformat_ [l=id] {Format tampilan:}
_textall_ [l=id] {semua}
_textquerymode_ [l=id] {Cara pertanyaan:}
_textsimplemode_ [l=id] { sederhana}
_textadvancedmode_ [l=id] { lanjutan (boleh mencari secara logika dengan menggunakan ! [tidak], & [dan], | [atau], dan tanda kurung)}
_textlinkinterm_ [l=id] {melalui halaman pengantara}
_textlinkdirect_ [l=id] {langsung tersedia}
_textdigitlib_ [l=id] {perpustakaan digital}
_textweb_ [l=id] {web}
_textgraphical_ [l=id] {grafis}
_texttextual_ [l=id] {teks}
_textcollectionoption_ [l=id] {<p>
Sub-koleksi yang tercantum:
<br>}
_textrelateddocdisplay_ [l=id] {tampilkan dokumen terkait}
_textsearchhistory_ [l=id] {Riwayat pencarian:}
_texthistorydisplay_ [l=id] { tampilkan _historynumrecords_ butir riwayat pencarian}
_textnohistorydisplay_ [l=id] { jangan tampilkan riwayat pencarian}

_texttypesearch_ [l=id] {Macam pencarian:}
_texttextsearch_ [l=id] {teks}
_textformsearch_ [l=id] {formulir}
_textqueryboxsize_ [l=id] {Ukuran kotak pertanyaan:}
_textregbox_ [l=id] { kotak pertanyaan biasa}
_textbigbox_ [l=id] { kotak pertanyaan besar}
_textformtype_ [l=id] {Tipe formulir:}
_textsimple_ [l=id] { sederhana}
_textadvanced_ [l=id] { lanjutan}

# used in "with 4 fields" in the form search box
_textwith_ [l=id] {dengan}
_textfields_ [l=id] {bidang}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "preferensi" ## green_title ## h_pref ##
_httpiconhpref_ [l=id] {_httpimg_/id/h\_pref.gif}
_widthhpref_ [l=id] {200}
_heighthpref_ [l=id] {57}

#####################################################################
# 'browse' package for the dynamic browsing interface
package browse
#####################################################################

_textbrowseby_ [l=id] {Melihat menurut}
_textthenby_ [l=id] {kemudian menurut}
_textshowing_ [l=id] {menampilkan}
_textdocsperpage_ [l=id] {dokumen per halaman}

_textfilterby_ [l=id] {Melihat hanya dokumen yang mengandung}
_textall_ [l=id] {semua}
_textany_ [l=id] {apa saja}
_textwords_ [l=id] {dari kata}

_browsebuttontext_ [l=id] {Melihat}


######################################################################
# 'help' page -- this is lower priority for translating than the
# rest of this file
package help
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textHelp_ [l=id] {Bantuan}
_textSearchshort_ [l=id] {mencari kata-kata tertentu}
_textSeriesshort_ [l=id] {mengakses publikasi menurut judul berkala}
_textDateshort_ [l=id] {mengakses publikasi menurut tanggal}
_textSubjectshort_ [l=id] {mengakses publikasi menurut subyek}
_textToshort_ [l=id] {mengakses publikasi menurut bidang Kepada}
_textFromshort_ [l=id] {mengakses publikasi menurut bidang Dari}
_textTitleshort_ [l=id] {mengakses publikasi menurut judul}
_textBrowseshort_ [l=id] {melihat publikasi}
_textCreatorshort_ [l=id] {mengakses publikasi menurut pengarang}
_textOrganizationshort_ [l=id] {mengakses publikasi menurut organisasi}
_textHowtoshort_ [l=id] {mengakses publikasi menurut daftar Bagaimana}
_textTopicshort_ [l=id] {mengakses publikasi menurut topik}
_textPeopleshort_ [l=id] {mengakses publikasi menurut orang}
_textLanguageshort_ [l=id] {mengakses publikasi menurut bahasa}
_textAcronymshort_ [l=id] {mengakses publikasi menurut singkatan}
_textPhraseshort_ [l=id] {melihat ungkapan yang berada di publikasi}
_textdefaultshorttext_ [l=id] {klasifikasi belum terdefinisi}

_textSearchlong_ [l=id] { <p>Anda dapat <i>mencari kata-kata tertentu</i> yang berada di teks dari halaman "Pencarian". Halaman inilah yang pertama mencul bila program dimulai. Halaman tsb dapat ditampilkan dengan menekan tombol <i>Mencari</i>.  }

_textTitlelong_ [l=id] { <p>Anda dapat <i>mengakses publikasi menurut judul</i> dengan menekan tombol <i>Judul A-Z</i>.  Tombol ini menampilkan daftar publikasi dalam urutan abjad.  }

_textOrganizationlong_ [l=id] { <p>Anda dapat <i>mengakses publikasi menurut organisasi</i> dengan menekan tombol <i>organisasi</i>.  Tombol ini menampilkan daftar organisasi.  }

_textHowtolong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut daftar "Bagaimana"</i> dengan menekan tombol <i>bagaimana</i>.  Tombol ini menampilkan daftar cara mengerjakan sesuatu.  }

_textCreatorlong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut pengarang</i> dengan menekan tombol <i>pengarang a-z</i>.  Tombol ini menampilkan daftar publikasi yang diurutkan menurut nama pengarang.  }

_textTopiclong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut topik</i> dengan menekan tombol <i>topik</i>.  Tombol ini menampilkan daftar topik yang dapat dipilih.  }

_textSubjectlong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut subyek</i> dengan menekan tombol <i>subyek</i>.  Tombol ini menampilkan daftar subyek, diwakili oleh rak buku.  }

_textTolong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut bidang "Kepada"</i> dengan menekan tombol <i>kepada</i>.  Tombol ini menampilkan daftar alamat.  }

_textFromlong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut bidang "Dari" </i> dengan menekan tombol <i>dari</i>.  Tombol ini menampilkan daftar pengirim. }

_textSerieslong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut judul seri (publikasi berkala)</i> dengan menekan tombol <i>berkala</i>.  Tombol ini menampilkan daftar publikasi berkala yang ada dalam koleksi.  }

_textDatelong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut tanggal</i> dengan menekan tombol <i>tanggal</i>.  Tombol ini menampilkan daftar publikasi berurutan tanggalnya.  }

_textBrowselong_ [l=id] { <p> Anda dapat <i>memilih dari daftar publikasi</i> dengan menekan tombol <i>melihat</i>.  }

_textPeoplelong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut perorangan</i> dengan menekan tombol <i>orang</i>.  Tombol ini menampilkan daftar perorangan dalam urutan abjad.  }

_textLanguagelong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut bahasa</i> dengan menekan tombol <i>bahasa</i>.  Tombol ini menampilkan daftar berurutan bahasa.  }

_textAcronymlong_ [l=id] { <p> Anda dapat <i>mengakses publikasi menurut singkatan</i> dengan menekan tombol <i>singkatan</i>.  Tombol ini menampilkan daftar singkatan dan letaknya.  }

_textPhraselong_ [l=id] { <p>You can <i>melihat ungkapan yang berada dalam publikasi</i> dengan menekan tombol <i>ungkapan</i> button.  Tombol ini menggunakan browser untuk mencari ungkapan.  }

_textdefaultlongtext_ [l=id] { <p>Klik pada tombol <i>tidak diketahui</i> untuk melihat publikasi (daftar diurutkan menurut bidang yang tidak diketahui).  }

_texthelptopics_ [l=id] {
<h2 align=left>Topik</h2>
<ul>
  <li><a href="\#finding-information">_textsimplehelpheading_</a>
  _topicreadingdocs_
  <li><a href="\#searching">Bagaimana mencari kata-kata tertentu </a>
<ul>
  <li><a href="\#query-terms">Istilah pencarian</a>
  <li><a href="\#query-type">Macam pertanyaan</a>
  <li><a href="\#scope-of-queries">Jangkauan pertanyaan</a>
</ul>
  <li><a href="\#preferences">_textchangeprefs_</a>
<ul>
  <li><a href="\#col-prefs">Preferensi koleksi</a>
  <li><a href="\#lang-prefs">Preferensi bahasa</a>
  <li><a href="\#pres-prefs">Preferensi penampilan</a>
  <li><a href="\#search-prefs">Preferensi pencarian</a>
</ul>
</ul>
}

# there are 4 versions of this section of the help text.
# which version is used is currently set within the server
# (it should probably use the macro language e.g. [type=book])
# 1 = html (like fao collections) -- section is empty
# 2 = book (like hdl collection) -- macros beginning with book
# 3 = bibliographic (like csbib) -- macros beginning with bib
# 4 = standard (like gberg) -- the default

_topicreadingdocs_ [l=id] {<li><a href="\#reading-docs">_textreadingdocs_</a>}

_textreadingdocs_ [l=id] {Bagaimana membaca dokumen}
_booktextreadingdocs_ [l=id] {Bagaimana membaca buku}
_bibtextreadingdocs_ [l=id] {Memperoleh informasi tambahan mengenai unsur bibliografi}

_texthelpreadingdocs_ [l=id] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Anda dapat mengetahui bahwa anda telah tiba di dokumen tertentu karena judul dan pengarangnya terlihat pada atas kiri halaman. Di sebelahnya ada nomor halaman yang ditampilkan, kotak yang memungkinkan anda untuk memilih halaman baru, dan panah maju dan mundur.

<p>Di bawahnya ada teks dari bagian yang terpilih. Bila anda sudah selesai membaca teks itu, panah di bawah dapat digunakan untuk maju ke bagian berikut atau mundur ke yang sebelumnya. 

<p>Di bawah judul dan pengarang terdapat tiga tombol. Klik pada <i>buka teks</i> untuk membuka semua teks dari dokumen terpilih. Bila dokumen besar, mungkin perlu menunggu lama dan banyak memori terpakai! Klik pada tombol <i>pisahkan</i> untuk membuka jendela baru untuk dokumen ini. (Hal ini dapat berguna bila anda ingin memperbandingkan dokumen, atau membaca dua dokumen sekaligus.)  Akhirnya, bila anda mencari kata tertentu, kata tersebut disoroti.  Klik pada tombol <i>tanpa penyorotan</i> untuk menghilangkan penyorotan.
<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_httpiconmore_" border="0"></td><td>Klik pada panah untuk maju ke bagian berikut ...</td></tr>
<tr><td colspan=2><img src="_httpiconless_" border="0"></td><td>... atau kembali ke bagian sebelumnya </td></tr>
<tr><td><img src="_document:httpiconealltof_" border="0"></td><td><img 
src="_document:httpiconetsecof_" border="0"></td><td>Tampilkan semua teks, atau tidak</td></tr>
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Buka halaman ini dalam jendela baru</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Menyoroti istilah yang dicari, atau tidak</td></tr>
</table>

}

_booktexthelpreadingdocs_ [l=id] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Anda dapat mengetahui bahwa anda telah tiba di buku tertentu karena foto sampulnya terlihat pada atas kiri halaman. Di sebelah foto itu ada daftar isi dengan panah yang menunjukkan letak anda Daftar tersebut dapat dibuka: klik pada map untuk membuka atau menutup map itu. Klik pada buku terbuka di paling atas untuk menutupnya.

<p> Di bawahnya ada teks dari bagian yang terpilih. Bila anda sudah selesai membaca teks itu, panah di bawah dapat digunakan untuk maju ke bagian berikut atau mundur ke yang sebelumnya. 

<p> Di bawah foto terdapat empat tombol. Klik pada <i>buka teks</i> untuk membuka semua teks dari buku atau bagian terpilih. Bila buku besar, mungkin perlu menunggu lama dan banyak memori terpakai! Klik pada tombol <i>pisahkan</i> untuk membuka jendela baru untuk dokumen ini. (Hal ini dapat berguna bila anda ingin memperbandingkan dokumen, atau membaca dua dokumen sekaligus.)  Akhirnya, bila anda mencari kata tertentu, kata tersebut disoroti.  Klik pada tombol <i>tanpa penyorotan</i> untuk menghilangkan penyorotan.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_httpiconbshelf_" border="0"></td><td>Buka rak buku ini</td></tr>
<tr><td><img src="_httpiconopenbook_" border="0"></td><td><img 
src="_httpiconbook_" border="0"></td><td>Buka/tutup buku ini</td></tr>
<tr><td colspan=2><img src="_httpiconitext_" border="0"></td><td>Melihat bagian teks ini</td></tr>
<tr><td><img src="_document:httpiconealltof_" border="0"></td><td><img 
src="_document:httpiconetsecof_" border="0"></td><td>Tampilkan semua teks, atau tidak</td></tr>
<tr><td><img src="_document:httpiconeexpcof_" border="0"></td><td><img
src="_document:httpiconeconcof_" border="0"></td><td>Buka daftar isi, atau tidak</td></tr>
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Buka halaman ini dalam jendela baru</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td>Menyoroti istilah yang dicari, atau tidak</td></tr>
<tr><td colspan=2><img src="_httpiconmore_" border="0"></td><td>Klik pada panah untuk maju ke bagian berikut ...</td></tr>
<tr><td colspan=2><img src="_httpiconless_" border="0"></td><td>... atau kembali ke bagian sebelumnya</td></tr>
</table>
}

_bibtexthelpreadingdocs_ [l=id] {
<p>_iconblankbar_
<a name=reading-docs>
<h2>_textreadingdocs_</h2>

<p>Beberapa unsur bibliografi mengandung informasi tambahan, seperti abstrak. Di halaman hasil pencarian, unsur yang mengandung informasi tambahan itu ditandai dengan lambang _icontext_ bukan dengan lambang _iconblanktext_.

<p>Klik pada lambang _icontext_ untuk memperoleh informasi tambahan mengenai unsur bibliografi.

<p> Di bawah bibliografi terdapat dua tombol. Klik pada tombol <i>pisahkan</i> untuk membuka jendela baru untuk dokumen ini. (Hal ini dapat berguna bila anda ingin memperbandingkan unsur bibliografi.)  Akhirnya, bila anda mencari kata tertentu, kata tersebut disoroti.  Klik pada tombol <i>tanpa penyorotan</i> untuk menghilangkan penyorotan.

<p>
<table cellspacing="0" cellpadding="2" border="0">
<tr><td colspan=2><img src="_document:httpiconedtchof_" border="0"></td><td>Buka halaman ini dalam jendela baru</td></tr>
<tr><td><img src="_document:httpiconehlof_" border="0"></td><td><img
src="_document:httpiconenhlof_" border="0"></td><td> Menyoroti istilah yang dicari, atau tidak</td></tr>
</table>
}

_texthelpsearching_ [l=id] {
<h2>Bagaimana mencari istilah tertentu</h2>
<p>
  Dari halaman Pencarian, anda dapat mengajukan pertanyaan dengan langkah berikut:<p>
  
  <ol><li>Memilih bahan yang ingin diselidiki 
      <li>Menentukan apakah anda ingin mencari semua atau hanya beberapa dari istilah 
      <li>Mengetik istilah yang dicari 
      <li>Klik pada tombol <i>Mulai mencari</i> 
  </ol>

<p>Bila pertanyaan diajukan, judul dari 20 dokumen yang sesuai akan ditampilkan. Tombol di ujung daftar tersebut dapat ditekan untuk menampilkan 20 dokumen berikutnya, kemudian 20 dokumen lagi, dst. Untuk melihat isi dokumen, klik pada judul dokumen itu, atau pada lambang di sisiknya. 

<p>Maksimal 100 dokumen dapat ditemukan. Jumlah ini dapat diganti dengan mengeklik pada tombol <i>preferensi</i> di atas halaman.<p>

<p>_iconblankbar_
<a name=query-terms>
<h3>Istilah pencarian</h3>

<p>Apa saja yang diketik dalam kotak pertanyaan dianggap sebagai daftar kata atau "istilah pencarian". Suatu istilah dapat mengandung hanya huruf A-Z dan angka 0-9. Istilah dipisahkan dengan spasi. Semua tanda lain (seperti tanda baca) dianggap sebagai spasi dan diabaikan. Kata yang mengandung tanda baca tidak dapat dicari.

<p>Misalnya, pertanyaan<p>
    <ul><kbd>Lada di Bangka-Belitung: Peluang untuk Agribisnis (1993)</kbd></ul>
      <p>dianggap sebagai<p>
      <ul><kbd> Lada di Bangka Belitung Peluang untuk Agribisnis 1993</kbd></ul><p>

<p>_iconblankbar_
<a name=query-type>
<h3>Macam pertanyaan</h3>

<p>Ada dua macam pertanyaan.

<ul>
  <li>Mencari <b>semua</b> kata. Pertanyaan ini mencari dokumen (atau bab atau 
      judul) yang mengandung semua kata yang diketik dalam kotak pertanyaan.
      Dokumen yang mengisi syarat itu ditampilkan dalan urutan abjad.<p>

  <li>Mencari <b>beberapa</b> dari kata. Ketikkan saja daftar istilah yang
      barangkali dimuat dalam dokumen yang dicari. Dokumen ditampilkan menurut
      kesesuaiannya pada pertanyaan itu. Dalam menentukan dekatnya kesesuaian,

      <p><ul>
        <li> makin banyak istilah yang dikandung dokumen, makin dekat kesesuaiannya;
        <li> istilah yang jarang dianggap lebih penting daripada istilah biasa;
        <li> dokumen pendek dianggap lebih dekat kesesuaiannya daripada dokumen panjang.
      </ul>
</ul>

<p>Anda dapat menggunakan sehendaknya banyak istilah pencarian--suatu kalimat penuh, atau bahkan alinea lengkap. Bila hanya satu istilah yang diketik, dokumen diurutkan menurut keseringan munculnya istilah itu.<p>
_texthelpscope_
}

_textdatesearch_ [l=id] {Mencari menurut tanggal}

_texthelpdatesearch_ [l=id] {<h2>_textdatesearch_</h2>
Pencarian menurut tanggal memungkinkan pencarian dokumen yang sesuai dengan istilah yang dipilih dan juga mengenai peristiwa dalam kurung waktu tertentu. Dokumen dapat dicari dari tahun tertentu atau dari kisaran tahun. Istilah pencarian tidak perlu: dokumen juga dapat dicari menurut tanggal saja. Tidak perlu menggunakan tanggal dalam pencarian: bila tanggal tidak diketik, maka tanggal diabaikan.<p>

<p>_iconblankbar_
<a name=datesearch-howto>
<h3>Bagaimana menggunakan fasilitas ini:</h3>
<ul>
   <li>Untuk mencari dokumen mengenai tahun tertentu:<p>
   <ul>
       <li>Masukkan istilah pencarian seperti biasa.	
       <li>Ketikkan tahun yang dimaksud pada kotak "Tahun mulai (atau tunggal)". 
       <li>Bila tahun yang dimaksud sebelum Masehi, pilihlah SM dari menu di sebelah. 
       <li>Mulailah pencarian seperti biasa.
   </ul>
<p><li>Untuk mencari dokumen mengenai kisaran tahun:<p>
   <ul>
       <li>Masukkan istilah pencarian seperti biasa.
       <li>Ketikkan tahun pertama pada kotak "Tahun mulai (atau tunggal)". 
       <li>Ketikkan tahun terakhir pada kotak "Tahun akhir".
       <li> Bila tahun yang dimaksud sebelum Masehi, pilihlah SM dari menu di sebelah. 
       <li> Mulailah pencarian seperti biasa.
   </ul>    
</ul><p>

<p>_iconblankbar_
<a name=datesearch-results>
<h3>Cara kerja pencarian</h3>

Pada umumnya, pencarian dokumen mengenai tahun 1903 tidak akan menemukan dokumen yang mengutip buku yang tertulis pada tahun 1903, hanya dokumen mengenai 1903. Akan tetapi, dokumen ditemukan yang mengandung kisaran tahun (seperti 1899-1911) yang mencakupi 1903. Juga ditemukan dokumen yang menyebut abad itu (misalnya abad ke-20 atau abad keduapuluh). Hal ini berarti bahwa tahun yang dicari tidak muncul di teks. Cara kerja ini juga berlaku untuk setiap tahun dalam pencarian kisaran.<p>
}

_textchangeprefs_ [l=id] {Mengubah preferensi}

_texthelppreferences_ [l=id] {<h2>_textchangeprefs_</h2>

<p>Dengan mengeklik pada tombol <i>preferensi</i> di atas halaman, anda dapat mengubah beberapa fasilitas dari penampilan supaya cocok dengan kebutuhan anda.

<p>_iconblankbar_
<a name=col-prefs>
<h3 align=left>Preferensi koleksi</h3>

Koleksi dapat terdiri dari beberapa sub-koleksi, yang dapat dicari secara tersendiri atau bersamaan. Pada koleksi macam itu, anda dapat memilih sub-koleksi yang mana untuk diselidiki pada halaman Preferensi.

<p>_iconblankbar_
<a name=lang-prefs>
<h3 align=left>Preferensi bahasa</h3>

Setiap koleksi ada bahasa penampilan yang standar, tetapi bahasa lain juga dapat dipilih. Anda juga dapat mengubah cara pengekodeaan yang digunakan oleh Greenstone untuk penyampaian hasil ke browser. Perangkat lunak memilih cara pengekodeaan secara otomatis, tetapi penampilan masih dapat diperbaiki di beberapa browser dengan memilih cara pengekodean yang lain. Semua koleksi memungkinkan pengantian penampilan grafis yang standar menjadi penampilan teks saja. Hal ini berguna untuk pengguna yang cacat mata yang memerlukan gaya huruf besar atau alat bicara untuk memperoleh keluaran.

<p>_iconblankbar_
<a name=pres-prefs>
<h3 align=left>Preferensi presentasi</h3>

Dalam koleksi tertentu, beberapa pilihan dapat disetel yang mengendalikan presentasi. 

<p>Di koleksi halaman web, mungkin menghilangkan menu navigasi Greenstone di atas setiap halaman, sehingga setelah menemukan halaman yang dicari, tidak ada kop Greenstone di atasnya. Untuk mencari lagi, harus menggunakan tombol "Back" (balik) di browser. Pada koleksi seperti itu juga mungkin menghilangkan pesan peringatan dari Greenstone yang ditampilkan bila anda klik pada link yang keluar dari koleksi dan masuk ke internet. Pada beberapa koleksi, mungkin mengendalikan apakah link di halaman "Hasil pencarian" meneruskan anda ke URL di internet, atau ke jiplakan halaman itu yang ada di koleksi. 

<p>_iconblankbar_
<a name=search-prefs>
<h3 align=left>Preferensi pencarian</h3>
<p>Dua pasangan tombol mengendalikan macam penyesuaian teks yang dilakukan dalam pencarian. Pasangan pertama ("Pembedaan huruf besar/kecil") mengatur apakah huruf besar dan kecil harus persis sama dengan apa yang diketik. Pasangan kedua ("Akhiran kata") mengatur apakah akhiran kata diabaikan atau tidak. Mungkin menampilkan kotak pertanyaan besar untuk mencari kalimat atau alinea. Pencarian alinea cukup cepat. 

<p>Misalnya, bila tombol <i>abaikan perbedaan</i> dan 
<i>abaikan akhiran</i> dipilih, pertanyaan<p>
    <ul><kbd>African building</kbd></ul>
      <p>akan dianggap sama dengan<p>
      <ul><kbd>africa builds</kbd></ul><p>karena huruf besar di "African" akan
      dijadikan huruf kecil, dan akhiran "n" dan "ing" dihapus dari "African"
      dan "building" ("s" juga dihapus dari "builds").

<p>Anda dapat pindah ke cara pencarian "lanjutan" yang memungkinkan penggunaan AND (&amp;) [dan], OR (|) [atau], dan NOT (!) [tidak]. Hal ini memungkinkan pertanyaan lebih spesifik. Anda juga dapat menggunakan fasilitas riwayat pencarian, yang menampilkan beberapa pertanyaan yang terakhir ditampilkan. Fasilitas ini memungkinkan pengulangan dari pertanyaan dulu dengan nada sedikit berbeda. Anda juga dapat mengendalikan jumlah dokumen yang ditemukan, serta jumlah yang ditampilkan pada setiap layar. 
}

_texttanumbrowseoptions_ [l=id] {Ada _numbrowseoptions_ cara untuk menemukan informasi dalam koleksi ini:}

_textsimplehelpheading_ [l=id] {Bagaimana mencari informasi}

_texthelpscope_ [l=id] {
<p>_iconblankbar_
<a name=scope-of-queries>
<h3 align=left>Jangkauan pertanyaan</h3>

<p>
Dalam sebagian besar dari koleksi, anda dapat memilih di antara beberapa indeks. Misalnya, mungkin ada indeks pengarang atau judul. Atau indeks bab atau alinea. Pada umumnya, dokumen penuh ditampilkan, tanpa memperhatikan indeks yang digunakan.
<p>Bila dokumen adalah buku, buku tsb dibuka pada tempat yang layak.
}
